@@ -5,14 +5,14 @@ use warnings;
 
 package Validation::Class;
 {
-    $Validation::Class::VERSION = '5.15';
+    $Validation::Class::VERSION = '5.20';
 }
 
 use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '5.15';    # VERSION
+our $VERSION = '5.20';    # VERSION
 
 use Module::Find;
 use Hash::Merge 'merge';
@@ -58,8 +58,6 @@ sub directive {
         validator => $data
     };
 
-    use strict 'refs';
-
     return $name, $data;
 
 }
@@ -79,8 +77,6 @@ sub field {
     $self->{config}->{FIELDS}->{$name} = $data;
     $self->{config}->{FIELDS}->{$name}->{errors} = [];
 
-    use strict 'refs';
-
     return $name, $data;
 
 }
@@ -99,8 +95,6 @@ sub filter {
 
     $self->{config}->{FILTERS}->{$name} = $data;
 
-    use strict 'refs';
-
     return $name, $data;
 
 }
@@ -111,10 +105,36 @@ sub load {
 
     my $self = caller(0);    # hackaroni toni
 
+    no strict 'refs';
+
     $self->load_classes() if $data->{classes};
 
     $self->load_plugins(@{$data->{plugins}}) if $data->{plugins};
 
+    # attached base classes (configs)
+    if ($data->{base}) {
+
+        if (@{$data->{base}}) {
+
+            foreach my $class (@{$data->{base}}) {
+
+                # require plugin
+                my $file = $class;
+                $file =~ s/::/\//g;
+                $file .= ".pm";
+
+                eval "require $class"
+                  unless $INC{$file};    # unless already loaded
+
+                # merge configs
+                $self->{config} = merge $class->{config}, $self->{config};
+
+            }
+
+        }
+
+    }
+
 }
 
 sub load_classes {
@@ -140,8 +160,6 @@ sub load_classes {
 
     }
 
-    use strict 'refs';
-
     return 0;
 
 }
@@ -174,8 +192,6 @@ sub load_plugins {
 
     $self->{config}->{PLUGINS}->{$_} = 1 for @plugins;
 
-    use strict 'refs';
-
     return 0;
 
 }
@@ -193,8 +209,6 @@ sub mixin {
 
     $self->{config}->{MIXINS}->{$name} = $data;
 
-    use strict 'refs';
-
     return $name, $data;
 
 }
@@ -262,8 +276,6 @@ sub profile {
 
     $self->{config}->{PROFILES}->{$name} = $data;
 
-    use strict 'refs';
-
     return $name, $data;
 
 }
@@ -280,7 +292,7 @@ Validation::Class - Low-Fat Full-Flavored Data Validation Construction Kit
 
 =head1 VERSION
 
-version 5.15
+version 5.20
 
 =head1 SYNOPSIS
 
@@ -1317,6 +1329,14 @@ prefixed with the name of the class being fetched, and adjust the matching rule
     my $kid3 = $rules->class('child'); # loads MyVal::Child;
     my $kid4 = $rules->class('step_child'); # loads MyVal::StepChild;
     
+    # INTELLIGENTLY DETECTING AND MAP PARAMS TO CHILD CLASS
+    my $params = {
+        'my.name'    => 'Guy Friday',
+        'child.name' => 'Guy Friday Jr.'
+    };
+    
+    $rules->class('child'); # child field *name* mapped to param *child.name*
+    
     # WITHOUT COPYING PARAMS FROM MyVal
     my $kid5 = $rules->class('child', params => {}); # .. etc
     
@@ -1480,10 +1500,23 @@ for configuring the current class.
     package MyVal;
     use Validation::Class;
     
+    # load all child classes (relatives)
+    load {
+        classes => 1 
+    };
+    
+    # load CPAN or Custom plugins
     load {
-        classes => 1, # same as above
         plugins => [
-            ...
+            'CPANPlugin',
+            '+MyVal::Plugin'
+        ]
+    };
+    
+    # merge configuration information from another class(es)
+    load {
+        base => [
+            'BaseClass'
         ]
     };
     
@@ -1491,7 +1524,7 @@ for configuring the current class.
 
 =head2 load_classes
 
-The load_classes method uses L<Module::Find> to load child classes for
+The load_classes method (B<depreciated>) uses L<Module::Find> to load child classes for
 convenient access through the class() method. Existing parameters and
 configuration options are passed to the child class's constructor. All
 attributes can be easily overwritten using the attribute's accessors on the
@@ -1512,7 +1545,7 @@ child class.
 
 =head2 load_plugins
 
-The load_plugins method is used to load plugins that support Validation::Class. 
+The load_plugins method (B<depreciated>) is used to load plugins that support Validation::Class. 
 A Validation::Class plugin is little more than a Role (Moose::Role) that extends
 the Validation::Class core. As usual, an official Validation::Class plugin can
 be referred to using shorthand while custom plugins are called by prefixing a
@@ -1627,6 +1660,17 @@ error stack of the current class.
 
     my $count = $self->set_errors('Oops', 'OMG', 'WTF');
 
+=head2 set_method
+
+The set_method method conveniently creates a method on the calling class, this
+method is primarily intended to be used during instantiation of a plugin during
+instantiation of the validation class.
+
+Additionally, method names are flattened, e.g. ThisPackage will be converted to
+this_package for convenience and consistency.
+
+    my $sub = $self->set_method(__PACKAGE__ => sub { ... });
+
 =head2 set_params_hash
 
 Depending on how parameters are being input into your application, if your
