@@ -3,14 +3,14 @@ use warnings;
 
 package Validation::Class::Engine;
 {
-    $Validation::Class::Engine::VERSION = '5.15';
+    $Validation::Class::Engine::VERSION = '5.20';
 }
 
 use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '5.15';    # VERSION
+our $VERSION = '5.20';    # VERSION
 
 use Carp 'confess';
 use Array::Unique;
@@ -634,6 +634,27 @@ sub set_errors {
 
 }
 
+sub set_method {
+
+    my ($self, $name, $code) = @_;
+
+    my $class = ref $self || $self;
+
+    my $shortname = $name;
+    $shortname =~ s/::/\_/;
+    $shortname =~ s/([a-z])([A-Z])/$1\_$2/g;
+
+    # place code on the calling class
+
+    confess "Error attempting to create method $shortname, already exists"
+      if defined &{"${class}::$shortname"};
+
+    no strict 'refs';
+
+    *{"${class}::$shortname"} = $code;
+
+}
+
 sub set_params_hash {
 
     my ($self, $params) = @_;
